---
meta:
  nav: Why Vuetify?
  title: Why Vuetify?
  description: Vuetify has an extremely active community, provides easy to use Material Design components and is consistently updated.
  keywords: why vuetify, best vue framework, best ui framework, best component framework, best ui library, best component library
related:
  - /getting-started/installation/
  - /introduction/roadmap/
  - /introduction/enterprise-support/
---

# Introduction

Learn more about what Vuetify is, how to create an application from scratch, browse API references, sample code, tutorials, and more.

<PageFeatures />

<VoPromotionsCardVuetify />

## What is Vuetify?

Since its initial release in 2014, [Vue.js](https://vuejs.org/) has grown to be among the most popular JavaScript frameworks in the world. One of the reasons for this popularity is the wide use of [components](https://vuejs.org/guide/essentials/component-basics.html) which enable developers to create small modules to be used and re-used throughout an application. Vuetify is a collection of pre-made components paired with powerful features such [dynamic themes](/features/theme/), [global defaults](/features/global-configuration/), [application layouts](/features/application-layout/), and more. Its goal is to provide developers with all of the necessary tools to build rich and engaging user experiences.

* [Why you should use it](#why-vuetify)
* [Features at a glance](#feature-guides)

## Getting started

<VoPromotionsCardHighlight slug="vuemastery-getting-started" class="mb-4" />

The fastest way to try Vuetify is in the browser at [Vuetify Play](https://play.vuetifyjs.com/). For a complete list of installation options please navigate to the [Installation page](/getting-started/installation/).

## Why Vuetify? { id="why-vuetify" }

Vuetify is a powerful Vue Component Framework built from the ground up to be easy to learn and rewarding to master. Our collection of UI components maintain a consistent style throughout your application with enough customization options to meet any use-case.

### It's free { id="its-free" }

Vuetify is an Open Source project available for free under the [MIT licensed](http://opensource.org/licenses/MIT). Additionally, Vuetify's source code is available on GitHub, allowing developers to modify and contribute to its development if they choose to do so.

### Flexible components

Every component in Vuetify is handcrafted under the guise of Google's [Material Design specification](https://material.io/) and comes with hundreds of customization options that fit any style or design; even if it's not Material. Write Vue templates that are as concise or verbose as you want using exclusively or in combination, **props**, **slots**, and **components**.

### Tooling

Vuetify has a large ecosystem of supporting tools that enrich the development experience that range from project creation to design UI kits.

* 🎨 [Figma UI Component Kit](https://store.vuetifyjs.com/products/vuetify-ui-kit-figma)
* ⚡ [First-party Vite support](https://github.com/vuetifyjs/vuetify-loader/tree/master/packages/vite-plugin)
* 🏗️ [Pre-configured Vue 3 applications for TypeScript and JavaScript](https://tryvuetify.com)
* ⌨️ Intellisense & autocomplete support for [VSCode](https://code.visualstudio.com/docs/editor/intellisense) and [JetBrains](https://www.jetbrains.com/help/rider/Auto-Completing_Code.html) products
* 🖼️ [Wireframe examples](/getting-started/wireframes/)

### Community

When you develop with Vuetify, you are never alone. Stuck on a problem? Take advantage of our massive [Discord community](https://community.vuetifyjs.com/) and collaborate with other Vuetify developers in one of our public help channels. Need a more personalized support solution? Vuetify offers [Enterprise support](/introduction/enterprise-support/) with options tailored to individuals and businesses. Check out some other ways to [Sponsor Vuetify development](/introduction/sponsors-and-backers/).

<PromotedPromoted slug="vuetify-discord" />

### Professional and Enterprise support

Vuetify offers an array of support services designed to help you get the most out of your application. Let our experience team provide you with the tools that you need to succeed with:

* ↗️ Vuetify version upgrades
* 📊 Performance review & analysis
* ⛑️ SLA & direct support

For more information regarding our professional support options, navigate to our [Enterprise support](/introduction/enterprise-support/) page.

### Active development

Vuetify has been in active development since 2016 and is constantly responding to community issues and reports at breakneck speed, allowing you to get your hands on bug fixes and enhancements more often. Our overall release cadence typically follows:

* 🔨 PATCH **(Weekly)**
* ⛏️ MINOR **(Quarterly)**
* ⚒️ MAJOR **(Bi-yearly to Yearly)**

In addition, after every MAJOR release, the previous version is still maintained with 18 months of [Long-term support](/introduction/long-term-support/).

So what are you waiting for? Head over to the [Installation](/getting-started/installation/) page and start building your next great idea today.

## Feature Guides

Learn more about the inner workings of Vuetify and become a skilled **v-developer** with our detailed feature guides. Each guide is designed to teach you how to get the most out of your development experience with information on: how to build responsive pages using [Layouts](/features/application-layout/), how to customize the style of your application with [SASS variables](/features/sass-variables/), and how to slim down your application's package size via [Treeshaking](/features/treeshaking/), and more.

| Feature | Skill level | Time to read |
| ------- | ----------- | ------------ |
| [Bidirectionality (LTR/RTL)](/features/internationalization/) | Beginner | 1 min |
| [Global configuration](/features/global-configuration/) | Beginner | 1 min |
| [Icon Fonts](/features/icon-fonts/) | Beginner | 15 min |
| [Layouts](/features/application-layout/) | Beginner | 5 min |
| [Theme](/features/theme/) | Beginner | 15 min |
| [Accessibility (a11y)](/features/accessibility) | Intermediate | 10 min |
| [Aliasing](/features/aliasing/) | Intermediate | 5 min |
| [Application layout](/features/application-layout/) | Intermediate | 15 min |
| [Dates](/features/dates/) | Intermediate | 10 min |
| [Display & Platform](/features/display-and-platform/) | Intermediate | 15 min |
| [Internationalization (i18n)](/features/internationalization/) | Intermediate | 5 min |
| [SASS variables](/features/sass-variables/) | Intermediate | 10 min |
| [Blueprints](/features/blueprints/) | Advanced | 10 min |
| [Treeshaking](/features/treeshaking/) | Advanced | 15 min |

Can't find what you're looking for? Help us improve! Please reach out to [hello@vuetifyjs.com](mailto:hello@vuetifyjs.com) with your feedback or join us in the Vuetify [Discord community](https://community.vuetifyjs.com/).
